/*
 * Accounts.java
 *
 * Created on June 14, 2006, 2:06 PM
 */

package com.localmatters.collector;

import java.io.Serializable;
import java.util.Collection;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;

/**
 * The accounts entity class.
 *
 * @author Daniel Cavalcanti
 * @version 1.0
 * @since 1.0
 */
@Entity()
@Table(name = "accounts")
@NamedQueries({
    @NamedQuery(name = "Accounts.findById", query = "SELECT a FROM Accounts a WHERE a.id = :id"),
    @NamedQuery(name = "Accounts.findByName", query = "SELECT a FROM Accounts a WHERE a.name = :name")
})
public class Accounts implements Serializable {
    
    // **********************************************************************
    // Instance variables
    // **********************************************************************
    
    /**
     * The account id.
     */
    @Id()
    @Column(name = "Id", nullable = false)
    private Integer id;
    
    /**
     * The account name.
     */
    @Column(name = "Name", nullable = false)
    private String name;
    
    /**
     * The transactions associated to this account.
     */
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "accountId")
    private Collection <Transactions> transactions;
    
    // **********************************************************************
    // Constructors
    // **********************************************************************
    
    /**
     * Creates a new instance of Accounts.
     */
    public Accounts() {
    }
    
    /**
     * Creates a new instance of Accounts.
     * 
     * @param id The account id.
     */
    public Accounts(Integer id) {
        this.id = id;
    }
    
    /**
     * Creates a new instance of Accounts.
     * 
     * @param id The account id.
     * @param name The account name.
     */
    public Accounts(Integer id, String name) {
        this.id = id;
        this.name = name;
    }
    
    // **********************************************************************
    // Getter/Setter methods
    // **********************************************************************
    
    /**
     * Returns the account id.
     *
     * @return The account id.
     */
    public Integer getId() {
        return this.id;
    }
    
    /**
     * Sets the account id.
     *
     * @param id The account id.
     */
    public void setId(Integer id) {
        this.id = id;
    }
    
    /**
     * Returns the account name.
     *
     * @return The account name.
     */
    public String getName() {
        return this.name;
    }
    
    /**
     * Sets the account name.
     *
     * @param name The account name.
     */
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * Returns the transactions associated to this account.
     *
     * @return The transactions associated to this account.
     */
    public Collection <Transactions> getTransactions() {
        return this.transactions;
    }
    
    /**
     * Sets the transactions associated to this account.
     *
     * @param transactions The transactions associated to this account.
     */
    public void setTransactions(Collection <Transactions> transactions) {
        this.transactions = transactions;
    }
    
    // **********************************************************************
    // Other methods
    // **********************************************************************
    
    /**
     * Returns the account hash code.
     *
     * @return The account hash code.
     */
    public int hashCode() {
        return (id != null ? id.hashCode() : 0);
    }
    
    /**
     * Determines if two accounts are equal. Two accounts are considered equal
     * iff their ids are equal.
     * 
     * @param object The other account.
     * @return true iff both accounts are equal, false otherwise.
     */
    public boolean equals(Object object) {
        if (object == null) return false;
        if (object instanceof Accounts) {
            Accounts other = (Accounts) object;
            if (id == null && other.id == null) return true;
            if (id == null || other.id == null) return false;
            return id.equals(other.id);
        } else return false;
    }
    
    /**
     * Returns a string representation of the account.
     *
     * @return A string representation of the account.
     */
    public String toString() {
        return this.id.toString();
    }
    
}
