/*
 * Transactions.java
 *
 * Created on June 14, 2006, 2:06 PM
 */

package com.localmatters.collector;

import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * The transactions entity class.
 *
 * @author Daniel Cavalcanti
 * @version 1.0
 * @since 1.0
 */
@Entity()
@Table(name = "transactions")
@NamedQueries({
    @NamedQuery(name = "Transactions.findById", query = "SELECT t FROM Transactions t WHERE t.id = :id"),
    @NamedQuery(name = "Transactions.findByTimestamp", query = "SELECT t FROM Transactions t WHERE t.timestamp = :timestamp")
})
public class Transactions implements Serializable {

    // **********************************************************************
    // Instance variables
    // **********************************************************************
    
    /**
     * The transaction id.
     */
    @Id()
    @Column(name = "Id", nullable = false)
    private Integer id;

    /**
     * The transaction time stamp.
     */
    @Column(name = "Timestamp", nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date timestamp;

    /**
     * The account this transaction is associated to.
     */
    @JoinColumn(name = "AccountId")
    @ManyToOne
    private Accounts accountId;

    /**
     * The user this transactions is associated to.
     */
    @JoinColumn(name = "UserId")
    @ManyToOne
    private com.localmatters.collector.Users userId;
    
    // **********************************************************************
    // Constructors
    // **********************************************************************
    
    /**
     * Creates a new instance of Transactions.
     */
    public Transactions() {
    }

    /**
     * Creates a new instance of Transactions.
     * 
     * @param id The transaction id.
     */
    public Transactions(Integer id) {
        this.id = id;
    }

    /**
     * Creates a new instance of Transactions.
     * 
     * @param id The transaction id.
     * @param timestamp The transaction time stamp.
     */
    public Transactions(Integer id, Date timestamp) {
        this.id = id;
        this.timestamp = timestamp;
    }

    // **********************************************************************
    // Getter/Setter methods
    // **********************************************************************
    
    /**
     * Returns the transaction id.
     *
     * @return The transaction id.
     */
    public Integer getId() {
        return this.id;
    }

    /**
     * Sets the transaction id.
     *
     * @param id The transaction id.
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * Returns the transaction time stamp.
     *
     * @return The transaction time stamp.
     */
    public Date getTimestamp() {
        return this.timestamp;
    }

    /**
     * Sets the transaction time stamp.
     *
     * @param timestamp The transaction time stamp.
     */
    public void setTimestamp(Date timestamp) {
        this.timestamp = timestamp;
    }

    /**
     * Returns the account this transaction is associated to.
     *
     * @return The account this transaction is associated to.
     */
    public Accounts getAccountId() {
        return this.accountId;
    }

    /**
     * Sets the account this transaction is associated to.
     *
     * @param accountId The account this transaction is associated to.
     */
    public void setAccountId(Accounts accountId) {
        this.accountId = accountId;
    }

    /**
     * Returns the user this transactions is associated to.
     *
     * @return The user this transactions is associated to.
     */
    public com.localmatters.collector.Users getUserId() {
        return this.userId;
    }

    /**
     * Sets the user this transactions is associated to.
     *
     * @param userId The user this transactions is associated to.
     */
    public void setUserId(com.localmatters.collector.Users userId) {
        this.userId = userId;
    }

    // **********************************************************************
    // Other methods
    // **********************************************************************
    
    /**
     * Returns the transaction hash code.
     *
     * @return The transaction hash code.
     */
    public int hashCode() {
        return (id != null ? id.hashCode() : 0);
    }

    /**
     * Determines if two transactions are equal. Two transactions are considered
     * equal iff their ids are equal.
     *
     * @param object The other transaction.
     * @return true iff both transactions are equal, false otherwise.
     */
    public boolean equals(Object object) {
        if (object == null) return false;
        if (object instanceof Transactions) {
            Transactions other = (Transactions) object;
            if (id == null && other.id == null) return true;
            if (id == null || other.id == null) return false;
            return id.equals(other.id);
        } else return false;
    }

    /**
     * Returns a string representation of transaction.
     *
     * @return A string representation of transaction.
     */
    public String toString() {
        return this.id.toString();
    }
    
}
