/*
 * Users.java
 *
 * Created on June 14, 2006, 2:06 PM
 */

package com.localmatters.collector;

import java.io.Serializable;
import java.util.Collection;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;

/**
 * The users entity class.
 *
 * @author Daniel Cavalcanti
 * @version 1.0
 * @since 1.0
 */
@Entity()
@Table(name = "users")
@NamedQueries({
    @NamedQuery(name = "Users.findById", query = "SELECT u FROM Users u WHERE u.id = :id"),
    @NamedQuery(name = "Users.findByUser", query = "SELECT u FROM Users u WHERE u.user = :user")
})
public class Users implements Serializable {

    // **********************************************************************
    // Instance variables
    // **********************************************************************
    
    /**
     * The user id.
     */
    @Id()
    @Column(name = "Id", nullable = false)
    private Integer id;

    /**
     * The user name.
     */
    @Column(name = "User", nullable = false)
    private String user;

    /**
     * The transactions associated to this user.
     */
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "userId")
    private Collection <Transactions> transactions;
    
    // **********************************************************************
    // Constructors
    // **********************************************************************
    
    /**
     * Creates a new instance of Users.
     */
    public Users() {
    }

    /**
     * Creates a new instance of Users.
     * 
     * @param id The user id.
     */
    public Users(Integer id) {
        this.id = id;
    }

    /**
     * Creates a new instance of Users.
     * 
     * @param id The user id.
     * @param user he user name.
     */
    public Users(Integer id, String user) {
        this.id = id;
        this.user = user;
    }

    // **********************************************************************
    // Getter/Setter methods
    // **********************************************************************
    
    /**
     * Returns the user id.
     *
     * @return The user id.
     */
    public Integer getId() {
        return this.id;
    }

    /**
     * Sets the user id.
     *
     * @param id The user id.
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * Returns the user name.
     *
     * @return The user name.
     */
    public String getUser() {
        return this.user;
    }

    /**
     * Sets the user name.
     *
     * @param user The user name.
     */
    public void setUser(String user) {
        this.user = user;
    }

    /**
     * Returns the transactions associated to this user.
     *
     * @return The transactions associated to this user.
     */
    public Collection <Transactions> getTransactions() {
        return this.transactions;
    }

    /**
     * Sets the transactions associated to this user.
     *
     * @param transactions The transactions associated to this user.
     */
    public void setTransactions(Collection <Transactions> transactions) {
        this.transactions = transactions;
    }

    // **********************************************************************
    // Other methods
    // **********************************************************************
    
    /**
     * Returns the user hash code.
     *
     * @return The user hash code.
     */
    public int hashCode() {
        return (id != null ? id.hashCode() : 0);
    }

    /**
     * Determines if two users are equal. Two users are considered equal iff
     * their ids are equal.
     * 
     * @param object The other user.
     * @return true iff both users are equal, false otherwise.
     */
    public boolean equals(Object object) {
        if (object == null) return false;
        if (object instanceof Users) {
            Users other = (Users) object;
            if (id == null && other.id == null) return true;
            if (id == null || other.id == null) return false;
            return id.equals(other.id);
        } else return false;
    }

    /**
     * Returns a string representation of the user.
     *
     * @return A string representation of the user.
     */
    public String toString() {
        return this.id.toString();
    }
    
}
